Package: animation
Type: Package
Title: A Gallery of Animations in Statistics and Utilities to Create
        Animations
Version: 2.8
Authors@R: c(
    person("Yihui", "Xie", role = c("aut", "cre"), email = "xie@yihui.name", comment = c(ORCID = "0000-0003-0645-5666", URL = "https://yihui.org")),
    person("Christian", "Mueller",role="ctb"),
    person("Lijia", "Yu", role=c("ctb"), email="yulj2010@gmail.com"),
    person("Xinyuan", "Chu", role="ctb"),
    person("Weicheng","Zhu",role="ctb")
    )
Description: Provides functions for animations in statistics, covering topics
    in probability theory, mathematical statistics, multivariate statistics,
    non-parametric statistics, sampling survey, linear models, time series,
    computational statistics, data mining and machine learning. These functions
    may be helpful in teaching statistics and data analysis. Also provided in this
    package are a series of functions to save animations to various formats, e.g.
    Flash, 'GIF', HTML pages, 'PDF' and videos. 'PDF' animations can be inserted
    into 'Sweave' / 'knitr' easily.
SystemRequirements: ImageMagick (http://imagemagick.org) or
        GraphicsMagick (http://www.graphicsmagick.org) or LyX
        (http://www.lyx.org) for saveGIF(); (PDF)LaTeX for saveLatex();
        SWF Tools (http://swftools.org) for saveSWF(); FFmpeg
        (http://ffmpeg.org) or avconv (https://libav.org/avconv.html)
        for saveVideo()
Depends: R (>= 2.14.0)
Imports: magick
Suggests: MASS, class, Cairo, fImport, rgl, zoo, testit
License: GPL
URL: https://yihui.org/animation/
BugReports: https://github.com/yihui/animation/issues
LazyData: yes
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-08-26 20:26:40 UTC; yihui
Author: Yihui Xie [aut, cre] (ORCID: <https://orcid.org/0000-0003-0645-5666>,
    URL: https://yihui.org),
  Christian Mueller [ctb],
  Lijia Yu [ctb],
  Xinyuan Chu [ctb],
  Weicheng Zhu [ctb]
Maintainer: Yihui Xie <xie@yihui.name>
Repository: CRAN
Date/Publication: 2025-08-26 23:40:12 UTC
