# Generated by roxygen2: do not edit by hand

export(BM.circle)
export(MC.hitormiss)
export(MC.samplemean)
export(Rosling.bubbles)
export(ani.options)
export(ani.pause)
export(ani.record)
export(ani.replay)
export(ani.start)
export(ani.stop)
export(bisection.method)
export(boot.iid)
export(boot.lowess)
export(brownian.motion)
export(buffon.needle)
export(clt.ani)
export(conf.int)
export(cv.ani)
export(cv.nfeaturesLDA)
export(ecol.death.sim)
export(flip.coin)
export(g.brownian.motion)
export(gm.convert)
export(grad.desc)
export(im.convert)
export(kfcv)
export(kmeans.ani)
export(knn.ani)
export(least.squares)
export(lln.ani)
export(moving.block)
export(mwar.ani)
export(newton.method)
export(pdftk)
export(price.ani)
export(qpdf)
export(quincunx)
export(quincunx2)
export(sample.cluster)
export(sample.ratio)
export(sample.simple)
export(sample.strat)
export(sample.system)
export(saveGIF)
export(saveHTML)
export(saveLatex)
export(saveSWF)
export(saveVideo)
export(sim.qqnorm)
export(vi.grid.illusion)
export(vi.lilac.chaser)
import(datasets)
import(grDevices)
import(graphics)
import(stats)
import(utils)
